@@ -1,8 +1,6 @@
-# frozen_string_literal: true
-
 class JsRegex
   module Converter
-    Dir[File.join(File.dirname(__FILE__), 'converter', '*.rb')].each do |file|
+    Dir[File.join(__dir__, 'converter', '*.rb')].sort.each do |file|
       require file
     end
 
