@@ -1,5 +1,3 @@
-# frozen_string_literal: true
-
 require_relative 'base'
 
 class JsRegex
@@ -23,9 +21,8 @@ class JsRegex
       end
 
       def pass_boundary_with_warning(boundary)
-        warn("The boundary '#{boundary}' at index #{expression.ts} "\
-             'is not unicode-aware in JavaScript, '\
-             'so it might act differently than in Ruby.')
+        warn_of("The anchor '#{boundary}' at index #{expression.ts} "\
+                'only works at ASCII word boundaries in JavaScript.')
         boundary
       end
     end
