@@ -1,5 +1,3 @@
-# frozen_string_literal: true
-
 require_relative 'base'
 
 class JsRegex
@@ -8,6 +6,9 @@ class JsRegex
     # Template class implementation.
     #
     class MetaConverter < JsRegex::Converter::Base
+      DOT_EXPANSION    = '(?:[\uD800-\uDBFF][\uDC00-\uDFFF]|[^\n\uD800-\uDFFF])'
+      ML_DOT_EXPANSION = '(?:[\uD800-\uDBFF][\uDC00-\uDFFF]|[^\uD800-\uDFFF])'
+
       private
 
       def convert_data
@@ -15,7 +16,7 @@ class JsRegex
         when :alternation
           convert_alternatives
         when :dot
-          expression.multiline? ? '(?:.|\n)' : '.'
+          expression.multiline? ? ML_DOT_EXPANSION : DOT_EXPANSION
         else
           warn_of_unsupported_feature
         end
